# fastfuzzysearch
[![codecov](https://codecov.io/gh/eyalsus/fastfuzzysearch/branch/main/graph/badge.svg?token=KXSFH7HSFM)](https://codecov.io/gh/eyalsus/fastfuzzysearch)

a Python package for fast fuzzy search entirely in-memory based
